import {
  Card,
  Collapse,
  Image,
  Space,
  Typography,
  Col,
  Row,
  List,
  Pagination,
} from "antd";
import Meta from "antd/lib/card/Meta";
import Title from "antd/lib/typography/Title";
import React, { useEffect, useState } from "react";
import { Link } from "react-router-dom";
import { CategoryIO, DirectorIO, MovieIO } from "./Preview";
import axiosConfig from "../axios-config";

const { Panel } = Collapse;
const { Paragraph } = Typography;

// for browsing movies by categories

const gridStyle: React.CSSProperties = {
  textAlign: "center",
  display: "flex",
};

export const BrowseMovies = () => {
  const [categories, setCategories] = useState<CategoryIO[]>([]);
  const [isError, setIsError] = useState<boolean>(false);

  useEffect(() => {
    const fetchCategories = async () => {
      try {
        const response = await axiosConfig.get("categories");
        setCategories(response.data);
      } catch (err) {
        setIsError(true);
      }
    };

    void fetchCategories();
  }, []);

  if (isError) {
    return <h3>Something went wrong…</h3>;
  }

  var panelNum = 0;
  return (
    <div className="browse-container">
      <Space direction="vertical" style={{ padding: "3rem", display: "flex"}} >
        <Collapse >
          {categories.map((category) => {
            panelNum += 1;
            return (
              <Panel header={category.name} key={panelNum}>
                
                  <List
                    grid={{
                      gutter: 4,
                      xs: 1,
                      sm: 2,
                      md: 2,
                      lg: 2,
                      xl: 2,
                      xxl: 6,
                    }}
                    dataSource={category.movies}
                    pagination={{
                      showSizeChanger: false,
                      responsive: true,
                      pageSize: 6
                    }}
                    renderItem={(movie) => (
                      <List.Item>
                        <Space
                          style={{
                            display: "flex",
                            justifyContent: "space-between",
                          }}
                        >
                          <Card
                            style={{ width: "16rem" }}
                            cover={
                              <Image
                                width={"16rem"}
                                style={{ objectFit: "cover" }}
                                src={movie.picture}
                              ></Image>
                            }
                          >
                            <Link to={`/movie/${movie.id}`}>
                              <Meta
                                title={movie.name}
                                description={
                                  <div>
                                    {movie.originalName}
                                    <br></br>
                                    {movie.publishedAt}
                                  </div>
                                }
                              ></Meta>
                            </Link>
                          </Card>
                        </Space>
                      </List.Item>
                    )}
                  />
              </Panel>
            );
          })}
        </Collapse>
      </Space>
    </div>
  );
};
